@@ -1,5 +1,5 @@
 package Net::HTTP::Methods;
-$Net::HTTP::Methods::VERSION = '6.12';
+$Net::HTTP::Methods::VERSION = '6.13';
 use strict;
 use warnings;
 use URI;
@@ -321,8 +321,8 @@ sub can_read {
         $before = time if $timeout;
         my $nfound = select($fbits, undef, undef, $timeout);
         if ($nfound < 0) {
-            if ($!{EINTR} || $!{EAGAIN}) {
-                # don't really think EAGAIN can happen here
+            if ($!{EINTR} || $!{EAGAIN} || $!{EWOULDBLOCK}) {
+                # don't really think EAGAIN/EWOULDBLOCK can happen here
                 if ($timeout) {
                     $timeout -= time - $before;
                     $timeout = 0 if $timeout < 0;
@@ -657,7 +657,7 @@ Net::HTTP::Methods
 
 =head1 VERSION
 
-version 6.12
+version 6.13
 
 =head1 AUTHOR
 
